from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.EgateType) -> None:
		"""SCPI: [SENSe]:SWEep:EGATe:TYPE \n
		Snippet: driver.applications.k30NoiseFigure.sense.sweep.egate.typePy.set(type_py = enums.EgateType.EDGE) \n
		This command selects the way gated measurements are triggered. \n
			:param type_py: LEVel The trigger event for the gate to open is a particular power level. After the gate signal has been detected, the gate remains open until the signal disappears. EDGE The trigger event for the gate to open is the detection of the signal edge. After the gate signal has been detected, the gate remains open until the gate length is over.
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.EgateType)
		self._core.io.write(f'SENSe:SWEep:EGATe:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.EgateType:
		"""SCPI: [SENSe]:SWEep:EGATe:TYPE \n
		Snippet: value: enums.EgateType = driver.applications.k30NoiseFigure.sense.sweep.egate.typePy.get() \n
		This command selects the way gated measurements are triggered. \n
			:return: type_py: LEVel The trigger event for the gate to open is a particular power level. After the gate signal has been detected, the gate remains open until the signal disappears. EDGE The trigger event for the gate to open is the detection of the signal edge. After the gate signal has been detected, the gate remains open until the gate length is over."""
		response = self._core.io.query_str(f'SENSe:SWEep:EGATe:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.EgateType)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def set(self, level: float) -> None:
		"""SCPI: SOURce:GENerator:LEVel \n
		Snippet: driver.source.generator.level.set(level = 1.0) \n
		This command defines the level of the signal that is generated by the signal source. \n
			:param level: numeric value Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce:GENerator:LEVel {param}')

	def get(self) -> float:
		"""SCPI: SOURce:GENerator:LEVel \n
		Snippet: value: float = driver.source.generator.level.get() \n
		This command defines the level of the signal that is generated by the signal source. \n
			:return: level: numeric value Unit: dBm"""
		response = self._core.io.query_str(f'SOURce:GENerator:LEVel?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ControlCls:
	"""Control commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("control", core, parent)

	def set(self, repetition: enums.HardcopyLogo) -> None:
		"""SCPI: HCOPy:TREPort:ITEM:LOGO:CONTrol \n
		Snippet: driver.hardCopy.treport.item.logo.control.set(repetition = enums.HardcopyLogo.ALWays) \n
		No command help available \n
			:param repetition: No help available
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.HardcopyLogo)
		self._core.io.write(f'HCOPy:TREPort:ITEM:LOGO:CONTrol {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.HardcopyLogo:
		"""SCPI: HCOPy:TREPort:ITEM:LOGO:CONTrol \n
		Snippet: value: enums.HardcopyLogo = driver.hardCopy.treport.item.logo.control.get() \n
		No command help available \n
			:return: repetition: No help available"""
		response = self._core.io.query_str(f'HCOPy:TREPort:ITEM:LOGO:CONTrol?')
		return Conversions.str_to_scalar_enum(response, enums.HardcopyLogo)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	# noinspection PyTypeChecker
	def get(self) -> enums.ServiceState:
		"""SCPI: DIAGnostic:SERVice:STATe \n
		Snippet: value: enums.ServiceState = driver.diagnostic.service.state.get() \n
		No command help available \n
			:return: state: No help available"""
		response = self._core.io.query_str(f'DIAGnostic:SERVice:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.ServiceState)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 2 total commands, 1 Subgroups, 1 group commands
	Repeated Capability: Trace, default value after init: Trace.Tr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_trace_get', 'repcap_trace_set', repcap.Trace.Tr1)

	def repcap_trace_set(self, trace: repcap.Trace) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Trace.Default
		Default value after init: Trace.Tr1"""
		self._cmd_group.set_repcap_enum_value(trace)

	def repcap_trace_get(self) -> repcap.Trace:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def relative(self):
		"""relative commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_relative'):
			from .Relative import RelativeCls
			self._relative = RelativeCls(self._core, self._cmd_group)
		return self._relative

	def get(self, meas_type: enums.AdemMeasType, window=repcap.Window.Default, marker=repcap.Marker.Default, trace=repcap.Trace.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:ADEMod:AM[:RESult<t>] \n
		Snippet: value: float = driver.calculate.marker.function.ademod.am.result.get(meas_type = enums.AdemMeasType.MIDDle, window = repcap.Window.Default, marker = repcap.Marker.Default, trace = repcap.Trace.Default) \n
		This command queries the current value of the demodulated signal for the specified trace (as displayed in the 'Result
		Summary' in manual operation) . Note that all windows with the same evaluation method have the same traces, thus the
		window is irrelevant. \n
			:param meas_type: PPEak | MPEak | MIDDle | RMS PPEak Postive peak (+PK) MPEak | NPEak Negative peak (-PK) MIDDle Average of positive and negative peaks ±PK/2 RMS Root mean square value
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Result')
			:return: meas_type_result: No help available"""
		param = Conversions.enum_scalar_to_str(meas_type, enums.AdemMeasType)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:ADEMod:AM:RESult{trace_cmd_val}? {param}')
		return Conversions.str_to_float(response)

	def clone(self) -> 'ResultCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ResultCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RdeviationCls:
	"""Rdeviation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rdeviation", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:FSK:RDEViation \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.fsk.rdeviation.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the reference deviation of FSK modulated signals. \n
			:param result_type: none Measurement deviation for current sweep. AVG Average FSK measurement deviation over several sweeps. RPE Peak FSK measurement deviation over several sweeps. SDEV Standard deviation of FSK measurement deviation. PCTL 95 percentile value of FSK measurement deviation.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:FSK:RDEViation? {param}')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OptimizationCls:
	"""Optimization commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("optimization", core, parent)

	def set(self, criterion: enums.OptimizationCriterion) -> None:
		"""SCPI: [SENSe]:DDEMod:OPTimization \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.optimization.set(criterion = enums.OptimizationCriterion.EVMMin) \n
		This command determines the optimization criteria for the demodulation. \n
			:param criterion: RMSMin | EVMMin RMSMin Optimizes calculation such that the RMS of the error vector is minimal. EVMMin Optimizes calculation such that EVM is minimal.
		"""
		param = Conversions.enum_scalar_to_str(criterion, enums.OptimizationCriterion)
		self._core.io.write(f'SENSe:DDEMod:OPTimization {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.OptimizationCriterion:
		"""SCPI: [SENSe]:DDEMod:OPTimization \n
		Snippet: value: enums.OptimizationCriterion = driver.applications.k70Vsa.sense.ddemod.optimization.get() \n
		This command determines the optimization criteria for the demodulation. \n
			:return: criterion: RMSMin | EVMMin RMSMin Optimizes calculation such that the RMS of the error vector is minimal. EVMMin Optimizes calculation such that EVM is minimal."""
		response = self._core.io.query_str(f'SENSe:DDEMod:OPTimization?')
		return Conversions.str_to_scalar_enum(response, enums.OptimizationCriterion)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CloggingCls:
	"""Clogging commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("clogging", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: SYSTem:CLOGging \n
		Snippet: driver.system.clogging.set(state = False) \n
		This command turns logging of remote commands on and off. \n
			:param state: ON | OFF | 1 | 0 ON | 1 Writes all remote commands that have been sent to a file. The destination is C:/R_S/INSTR/ScpiLogging/ ScpiLog.no.. where no. is a sequential number A new log file is started each time logging was stopped and is restarted. OFF | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SYSTem:CLOGging {param}')

	def get(self) -> bool:
		"""SCPI: SYSTem:CLOGging \n
		Snippet: value: bool = driver.system.clogging.get() \n
		This command turns logging of remote commands on and off. \n
			:return: state: ON | OFF | 1 | 0 ON | 1 Writes all remote commands that have been sent to a file. The destination is C:/R_S/INSTR/ScpiLogging/ ScpiLog.no.. where no. is a sequential number A new log file is started each time logging was stopped and is restarted. OFF | 0"""
		response = self._core.io.query_str(f'SYSTem:CLOGging?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, frame_mode: enums.ConfigMode) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:MODE \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.frame.mode.set(frame_mode = enums.ConfigMode.DEFault) \n
		Determines whether the frame structure of the signal is configured in reference to the result range or user-defined. This
		command is only available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:param frame_mode: DEFault | USER Default A single frame is assumed to correspond to the result range defined by [SENSe:]DDEMod:TIME. User-Defined A frame is defined manually as a succession of subframes with specified characteristics. In this case, the result range is assumed to be a single frame as specified by [SENSe:]DDEMod:PATTern:FRAMe:EDIT:STRucture. If no structure is configured or loaded yet, the result range definition is used (as for 'Default') .
		"""
		param = Conversions.enum_scalar_to_str(frame_mode, enums.ConfigMode)
		self._core.io.write(f'SENSe:DDEMod:PATTern:FRAMe:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ConfigMode:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:MODE \n
		Snippet: value: enums.ConfigMode = driver.applications.k70Vsa.sense.ddemod.pattern.frame.mode.get() \n
		Determines whether the frame structure of the signal is configured in reference to the result range or user-defined. This
		command is only available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:return: frame_mode: DEFault | USER Default A single frame is assumed to correspond to the result range defined by [SENSe:]DDEMod:TIME. User-Defined A frame is defined manually as a succession of subframes with specified characteristics. In this case, the result range is assumed to be a single frame as specified by [SENSe:]DDEMod:PATTern:FRAMe:EDIT:STRucture. If no structure is configured or loaded yet, the result range definition is used (as for 'Default') ."""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:FRAMe:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ConfigMode)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CalibrationCls:
	"""Calibration commands group definition. 9 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("calibration", core, parent)

	@property
	def aiq(self):
		"""aiq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_aiq'):
			from .Aiq import AiqCls
			self._aiq = AiqCls(self._core, self._cmd_group)
		return self._aiq

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def due(self):
		"""due commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_due'):
			from .Due import DueCls
			self._due = DueCls(self._core, self._cmd_group)
		return self._due

	@property
	def preSelection(self):
		"""preSelection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_preSelection'):
			from .PreSelection import PreSelectionCls
			self._preSelection = PreSelectionCls(self._core, self._cmd_group)
		return self._preSelection

	@property
	def result(self):
		"""result commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_result'):
			from .Result import ResultCls
			self._result = ResultCls(self._core, self._cmd_group)
		return self._result

	def clone(self) -> 'CalibrationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CalibrationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, meas_only_on_patt: enums.SyncMode) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:MODE \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.sync.mode.set(meas_only_on_patt = enums.SyncMode.MEAS) \n
		This command sets the vector analyzer so that the measurement is performed only if the measurement was synchronous to the
		selected sync pattern. The command is available only if the pattern search is activated (see
		[SENSe:]DDEMod:SEARch:SYNC:STATe) . \n
			:param meas_only_on_patt: MEAS | SYNC MEAS The measurement is performed independently of successful synchronization SYNC The measured values are displayed and considered in the error evaluation only if the set sync pattern was found. Bursts with a wrong sync pattern (sync not found) are ignored. If an invalid or no sync pattern is found, the measurement waits and resumes running only when a valid sync pattern is found.
		"""
		param = Conversions.enum_scalar_to_str(meas_only_on_patt, enums.SyncMode)
		self._core.io.write(f'SENSe:DDEMod:SEARch:SYNC:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SyncMode:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:MODE \n
		Snippet: value: enums.SyncMode = driver.applications.k70Vsa.sense.ddemod.search.sync.mode.get() \n
		This command sets the vector analyzer so that the measurement is performed only if the measurement was synchronous to the
		selected sync pattern. The command is available only if the pattern search is activated (see
		[SENSe:]DDEMod:SEARch:SYNC:STATe) . \n
			:return: meas_only_on_patt: MEAS | SYNC MEAS The measurement is performed independently of successful synchronization SYNC The measured values are displayed and considered in the error evaluation only if the set sync pattern was found. Bursts with a wrong sync pattern (sync not found) are ignored. If an invalid or no sync pattern is found, the measurement waits and resumes running only when a valid sync pattern is found."""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:SYNC:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.SyncMode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WselectCls:
	"""Wselect commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("wselect", core, parent)

	def get(self) -> int:
		"""SCPI: DISPlay:WSELect \n
		Snippet: value: int = driver.applications.k50Spurious.display.wselect.get() \n
		No command help available \n
			:return: selected_window: No help available"""
		response = self._core.io.query_str(f'DISPlay:WSELect?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, reference: enums.TraceReference, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: CALCulate<n>:TRACe<t>:ADJust[:VALue] \n
		Snippet: driver.applications.k70Vsa.calculate.trace.adjust.value.set(reference = enums.TraceReference.BURSt, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command defines the reference point for the display. \n
			:param reference: TRIGger | BURSt | PATTern TRIGger The reference point is defined by the start of the capture buffer. BURSt The reference point is defined by the start/center/end of the burst. PATTern The instrument selects the reference point and the alignment.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(reference, enums.TraceReference)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:ADJust:VALue {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> enums.TraceReference:
		"""SCPI: CALCulate<n>:TRACe<t>:ADJust[:VALue] \n
		Snippet: value: enums.TraceReference = driver.applications.k70Vsa.calculate.trace.adjust.value.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command defines the reference point for the display. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: reference: TRIGger | BURSt | PATTern TRIGger The reference point is defined by the start of the capture buffer. BURSt The reference point is defined by the start/center/end of the burst. PATTern The instrument selects the reference point and the alignment."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:ADJust:VALue?')
		return Conversions.str_to_scalar_enum(response, enums.TraceReference)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Seconds: float: No parameter help available
			- Nanoseconds: float: No parameter help available
			- Reserved: float: No parameter help available
			- Reserved_B: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Seconds'),
			ArgStruct.scalar_float('Nanoseconds'),
			ArgStruct.scalar_float('Reserved'),
			ArgStruct.scalar_float('Reserved_B')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Seconds: float = None
			self.Nanoseconds: float = None
			self.Reserved: float = None
			self.Reserved_B: float = None

	def get(self, frames: enums.SelectionRangeB, window=repcap.Window.Default) -> GetStruct:
		"""SCPI: CALCulate<n>:SPECtrogram:TSTamp:DATA \n
		Snippet: value: GetStruct = driver.calculate.spectrogram.tstamp.data.get(frames = enums.SelectionRangeB.ALL, window = repcap.Window.Default) \n
		No command help available \n
			:param frames: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		param = Conversions.enum_scalar_to_str(frames, enums.SelectionRangeB)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:SPECtrogram:TSTamp:DATA? {param}', self.__class__.GetStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MspurCls:
	"""Mspur commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mspur", core, parent)

	def set(self, type_py: enums.MspurSearchType) -> None:
		"""SCPI: [SENSe]:SSEarch:MSPur \n
		Snippet: driver.applications.k50Spurious.sense.ssearch.mspur.set(type_py = enums.MspurSearchType.DMINimum) \n
		Defines the condition for matching the measured to the predicted spurs. \n
			:param type_py: DMINimum | PMAXimum DMINimum If multiple measured spurs are inside the tolerance range around a predicted spur, the measured spur closest to the predicted spur is identified as the predicted. PMAXimum If multiple measured spurs are inside the tolerance range around a predicted spur, the measured spur with the highest power will be identified as the predicted.
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.MspurSearchType)
		self._core.io.write(f'SENSe:SSEarch:MSPur {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.MspurSearchType:
		"""SCPI: [SENSe]:SSEarch:MSPur \n
		Snippet: value: enums.MspurSearchType = driver.applications.k50Spurious.sense.ssearch.mspur.get() \n
		Defines the condition for matching the measured to the predicted spurs. \n
			:return: type_py: DMINimum | PMAXimum DMINimum If multiple measured spurs are inside the tolerance range around a predicted spur, the measured spur closest to the predicted spur is identified as the predicted. PMAXimum If multiple measured spurs are inside the tolerance range around a predicted spur, the measured spur with the highest power will be identified as the predicted."""
		response = self._core.io.query_str(f'SENSe:SSEarch:MSPur?')
		return Conversions.str_to_scalar_enum(response, enums.MspurSearchType)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def get(self, inputIx=repcap.InputIx.Default) -> float:
		"""SCPI: INPut<ip>:UPORt[:VALue] \n
		Snippet: value: float = driver.inputPy.uport.value.get(inputIx = repcap.InputIx.Default) \n
		This command queries the control lines of the user ports. For details see method RsFswp.Output.Uport.Value.set. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: level: bit values in hexadecimal format TTL type voltage levels (max. 5V) Range: #B00000000 to #B00111111"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:UPORt:VALue?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OscCls:
	"""Osc commands group definition. 10 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("osc", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def tcpip(self):
		"""tcpip commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tcpip'):
			from .Tcpip import TcpipCls
			self._tcpip = TcpipCls(self._core, self._cmd_group)
		return self._tcpip

	@property
	def balanced(self):
		"""balanced commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_balanced'):
			from .Balanced import BalancedCls
			self._balanced = BalancedCls(self._core, self._cmd_group)
		return self._balanced

	@property
	def fullscale(self):
		"""fullscale commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fullscale'):
			from .Fullscale import FullscaleCls
			self._fullscale = FullscaleCls(self._core, self._cmd_group)
		return self._fullscale

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	@property
	def skew(self):
		"""skew commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_skew'):
			from .Skew import SkewCls
			self._skew = SkewCls(self._core, self._cmd_group)
		return self._skew

	def clone(self) -> 'OscCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = OscCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PatternsCls:
	"""Patterns commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("patterns", core, parent)

	def get(self, window=repcap.Window.Default) -> int:
		"""SCPI: CALCulate<n>:DSP:RESult:CAPTure:PATTerns \n
		Snippet: value: int = driver.applications.k70Vsa.calculate.dsp.result.capture.patterns.get(window = repcap.Window.Default) \n
		Queries the number of patterns found across the internal capture buffer. Note that the internal capture buffer is
		slightly larger than the displayed capture buffer in order to allow for sufficient filter settling times for further
		processing. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: patterns: integer Number of patterns"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DSP:RESult:CAPTure:PATTerns?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPyCls:
	"""ListPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- System_Messages: str: String containing all messages in the 'System Messages' table.
			- Remote_Errors: str: Error_no| Description| Command| Date| Time Comma-separated list of errors from the 'Remote Errors' table, where: Error_no: device-specific error code Description: brief description of the error Command: remote command causing the error Date|Time: date and time the error occurred"""
		__meta_args_list = [
			ArgStruct.scalar_str('System_Messages'),
			ArgStruct.scalar_raw_str('Remote_Errors')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.System_Messages: str = None
			self.Remote_Errors: str = None

	def get(self, mess_type: enums.MessageType = None) -> GetStruct:
		"""SCPI: SYSTem:ERRor:LIST \n
		Snippet: value: GetStruct = driver.system.error.listPy.get(mess_type = enums.MessageType.REMote) \n
		This command queries the error messages that occur during R&S FSWP operation. \n
			:param mess_type: SMSG | REMote SMSG (default) Queries the system messages which occurred during manual operation. REMote Queries the error messages that occurred during remote operation. Note: The remote error list is automatically cleared when the R&S FSWP is shut down.
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('mess_type', mess_type, DataType.Enum, enums.MessageType, is_optional=True))
		return self._core.io.query_struct(f'SYSTem:ERRor:LIST? {param}'.rstrip(), self.__class__.GetStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdentityCls:
	"""Identity commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("identity", core, parent)

	def set(self, type_py: enums.MixerIdentifier, component=repcap.Component.Default) -> None:
		"""SCPI: [SENSe]:FPLan:COMPonent<co>:IDENtity \n
		Snippet: driver.applications.k50Spurious.sense.fplan.component.identity.set(type_py = enums.MixerIdentifier.CLOCk, component = repcap.Component.Default) \n
		Selects the identifier for the second input frequency for mixers. \n
			:param type_py: LO | CLOCk
			:param component: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Component')
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.MixerIdentifier)
		component_cmd_val = self._cmd_group.get_repcap_cmd_value(component, repcap.Component)
		self._core.io.write(f'SENSe:FPLan:COMPonent{component_cmd_val}:IDENtity {param}')

	# noinspection PyTypeChecker
	def get(self, component=repcap.Component.Default) -> enums.MixerIdentifier:
		"""SCPI: [SENSe]:FPLan:COMPonent<co>:IDENtity \n
		Snippet: value: enums.MixerIdentifier = driver.applications.k50Spurious.sense.fplan.component.identity.get(component = repcap.Component.Default) \n
		Selects the identifier for the second input frequency for mixers. \n
			:param component: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Component')
			:return: type_py: LO | CLOCk"""
		component_cmd_val = self._cmd_group.get_repcap_cmd_value(component, repcap.Component)
		response = self._core.io.query_str(f'SENSe:FPLan:COMPonent{component_cmd_val}:IDENtity?')
		return Conversions.str_to_scalar_enum(response, enums.MixerIdentifier)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EnableCls:
	"""Enable commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("enable", core, parent)

	def set(self, bit_definition: int, channel_name: str = None, window=repcap.Window.Default) -> None:
		"""SCPI: STATus:QUEStionable:MODulation<Window>:ENABle \n
		Snippet: driver.applications.k70Vsa.status.questionable.modulation.enable.set(bit_definition = 1, channel_name = '1', window = repcap.Window.Default) \n
		This command controls the ENABle part of a register. The ENABle part allows true conditions in the EVENt part of the
		status register to be reported in the summary bit. If a bit is 1 in the enable register and its associated event bit
		transitions to true, a positive transition will occur in the summary bit reported to the next higher level. \n
			:param bit_definition: Range: 0 to 65535
			:param channel_name: String containing the name of the channel. The parameter is optional. If you omit it, the command works for the currently active channel.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Modulation')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('bit_definition', bit_definition, DataType.Integer), ArgSingle('channel_name', channel_name, DataType.String, None, is_optional=True))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'STATus:QUEStionable:MODulation{window_cmd_val}:ENABle {param}'.rstrip())

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Response structure. Fields: \n
			- Bit_Definition: int: Range: 0 to 65535
			- Channel_Name: str: String containing the name of the channel. The parameter is optional. If you omit it, the command works for the currently active channel."""
		__meta_args_list = [
			ArgStruct.scalar_int('Bit_Definition'),
			ArgStruct.scalar_str('Channel_Name')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Bit_Definition: int = None
			self.Channel_Name: str = None

	def get(self, window=repcap.Window.Default) -> EnableStruct:
		"""SCPI: STATus:QUEStionable:MODulation<Window>:ENABle \n
		Snippet: value: EnableStruct = driver.applications.k70Vsa.status.questionable.modulation.enable.get(window = repcap.Window.Default) \n
		This command controls the ENABle part of a register. The ENABle part allows true conditions in the EVENt part of the
		status register to be reported in the summary bit. If a bit is 1 in the enable register and its associated event bit
		transitions to true, a positive transition will occur in the summary bit reported to the next higher level. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Modulation')
			:return: structure: for return value, see the help for EnableStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'STATus:QUEStionable:MODulation{window_cmd_val}:ENABle?', self.__class__.EnableStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LxiCls:
	"""Lxi commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lxi", core, parent)

	@property
	def lanReset(self):
		"""lanReset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lanReset'):
			from .LanReset import LanResetCls
			self._lanReset = LanResetCls(self._core, self._cmd_group)
		return self._lanReset

	@property
	def mdescription(self):
		"""mdescription commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mdescription'):
			from .Mdescription import MdescriptionCls
			self._mdescription = MdescriptionCls(self._core, self._cmd_group)
		return self._mdescription

	@property
	def password(self):
		"""password commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_password'):
			from .Password import PasswordCls
			self._password = PasswordCls(self._core, self._cmd_group)
		return self._password

	@property
	def info(self):
		"""info commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_info'):
			from .Info import InfoCls
			self._info = InfoCls(self._core, self._cmd_group)
		return self._info

	def clone(self) -> 'LxiCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LxiCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MeasCls:
	"""Meas commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("meas", core, parent)

	def set(self, file: str) -> None:
		"""SCPI: MMEMory:STORe:SPUR:MEAS \n
		Snippet: driver.applications.k50Spurious.massMemory.store.spur.meas.set(file = '1') \n
		This command stores the current measurement results (all enabled traces and tables of all windows) into the specified csv
		file. The results are output in the same order as they are displayed on the screen: window by window, trace by trace, and
		table row by table row. \n
			:param file: No help available
		"""
		param = Conversions.value_to_quoted_str(file)
		self._core.io.write(f'MMEMory:STORe:SPUR:MEAS {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StartCls:
	"""Start commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	def set(self, time: float, trace=repcap.Trace.Default, gateRange=repcap.GateRange.Nr1) -> None:
		"""SCPI: [SENSe]:SWEep:EGATe:TRACe<t>:STARt<gr> \n
		Snippet: driver.sense.sweep.egate.trace.start.set(time = 1.0, trace = repcap.Trace.Default, gateRange = repcap.GateRange.Nr1) \n
		No command help available \n
			:param time: No help available
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:param gateRange: optional repeated capability selector. Default value: Nr1
		"""
		param = Conversions.decimal_value_to_str(time)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		gateRange_cmd_val = self._cmd_group.get_repcap_cmd_value(gateRange, repcap.GateRange)
		self._core.io.write(f'SENSe:SWEep:EGATe:TRACe{trace_cmd_val}:STARt{gateRange_cmd_val} {param}')

	def get(self, trace=repcap.Trace.Default, gateRange=repcap.GateRange.Nr1) -> float:
		"""SCPI: [SENSe]:SWEep:EGATe:TRACe<t>:STARt<gr> \n
		Snippet: value: float = driver.sense.sweep.egate.trace.start.get(trace = repcap.Trace.Default, gateRange = repcap.GateRange.Nr1) \n
		No command help available \n
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:param gateRange: optional repeated capability selector. Default value: Nr1
			:return: time: No help available"""
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		gateRange_cmd_val = self._cmd_group.get_repcap_cmd_value(gateRange, repcap.GateRange)
		response = self._core.io.query_str(f'SENSe:SWEep:EGATe:TRACe{trace_cmd_val}:STARt{gateRange_cmd_val}?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TraceCls:
	"""Trace commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trace", core, parent)

	def set(self, trace: int, filename: str, store=repcap.Store.Default) -> None:
		"""SCPI: MMEMory:STORe<n>:TRACe \n
		Snippet: driver.applications.k50Spurious.massMemory.store.trace.set(trace = 1, filename = '1', store = repcap.Store.Default) \n
		This command exports trace data from the specified window to an ASCII file. Secure User Mode In secure user mode,
		settings that are stored on the instrument are stored to volatile memory, which is restricted to 256 MB. Thus, a 'memory
		limit reached' error can occur although the hard disk indicates that storage space is still available. To store data
		permanently, select an external storage location such as a USB memory device. \n
			:param trace: Number of the trace to be stored
			:param filename: String containing the path and name of the target file.
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('trace', trace, DataType.Integer), ArgSingle('filename', filename, DataType.String))
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		self._core.io.write(f'MMEMory:STORe{store_cmd_val}:TRACe {param}'.rstrip())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.PwrLevelMode, source=repcap.Source.Default) -> None:
		"""SCPI: SOURce:VOLTage:POWer<1|2>:LEVel:MODE \n
		Snippet: driver.source.voltage.power.level.mode.set(mode = enums.PwrLevelMode.CURRent, source = repcap.Source.Default) \n
		This command selects whether you want to control the output in terms of current or voltage. \n
			:param mode: CURRent Control the output in terms of current. VOLTage Controls the output in terms of voltage.
			:param source: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.PwrLevelMode)
		source_cmd_val = self._cmd_group.get_repcap_cmd_value(source, repcap.Source)
		self._core.io.write(f'SOURce:VOLTage:POWer{source_cmd_val}:LEVel:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, source=repcap.Source.Default) -> enums.PwrLevelMode:
		"""SCPI: SOURce:VOLTage:POWer<1|2>:LEVel:MODE \n
		Snippet: value: enums.PwrLevelMode = driver.source.voltage.power.level.mode.get(source = repcap.Source.Default) \n
		This command selects whether you want to control the output in terms of current or voltage. \n
			:param source: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
			:return: mode: CURRent Control the output in terms of current. VOLTage Controls the output in terms of voltage."""
		source_cmd_val = self._cmd_group.get_repcap_cmd_value(source, repcap.Source)
		response = self._core.io.query_str(f'SOURce:VOLTage:POWer{source_cmd_val}:LEVel:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.PwrLevelMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StartCls:
	"""Start commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	@property
	def function(self):
		"""function commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_function'):
			from .Function import FunctionCls
			self._function = FunctionCls(self._core, self._cmd_group)
		return self._function

	@property
	def abs(self):
		"""abs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_abs'):
			from .Abs import AbsCls
			self._abs = AbsCls(self._core, self._cmd_group)
		return self._abs

	def set(self, level: float, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>:LIMit<li>:RELative:STARt \n
		Snippet: driver.sense.espectrum.range.limit.relative.start.set(level = 1.0, subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default, limitIx = repcap.LimitIx.Default) \n
		No command help available \n
			:param level: No help available
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.decimal_value_to_str(level)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:LIMit{limitIx_cmd_val}:RELative:STARt {param}')

	def get(self, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default, limitIx=repcap.LimitIx.Default) -> float:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>:LIMit<li>:RELative:STARt \n
		Snippet: value: float = driver.sense.espectrum.range.limit.relative.start.get(subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default, limitIx = repcap.LimitIx.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: level: No help available"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:LIMit{limitIx_cmd_val}:RELative:STARt?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'StartCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = StartCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, max_peak: float) -> None:
		"""SCPI: [SENSe]:CREFerence:VALue \n
		Snippet: driver.applications.k50Spurious.sense.creference.value.set(max_peak = 1.0) \n
		Defines the maximum peak of the signal, which is considered to be the reference carrier. \n
			:param max_peak: Unit: DBM
		"""
		param = Conversions.decimal_value_to_str(max_peak)
		self._core.io.write(f'SENSe:CREFerence:VALue {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CREFerence:VALue \n
		Snippet: value: float = driver.applications.k50Spurious.sense.creference.value.get() \n
		Defines the maximum peak of the signal, which is considered to be the reference carrier. \n
			:return: max_peak: Unit: DBM"""
		response = self._core.io.query_str(f'SENSe:CREFerence:VALue?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UncertaintyCls:
	"""Uncertainty commands group definition. 29 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uncertainty", core, parent)

	@property
	def sanalyzer(self):
		"""sanalyzer commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_sanalyzer'):
			from .Sanalyzer import SanalyzerCls
			self._sanalyzer = SanalyzerCls(self._core, self._cmd_group)
		return self._sanalyzer

	@property
	def result(self):
		"""result commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_result'):
			from .Result import ResultCls
			self._result = ResultCls(self._core, self._cmd_group)
		return self._result

	@property
	def common(self):
		"""common commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_common'):
			from .Common import CommonCls
			self._common = CommonCls(self._core, self._cmd_group)
		return self._common

	@property
	def preamp(self):
		"""preamp commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_preamp'):
			from .Preamp import PreampCls
			self._preamp = PreampCls(self._core, self._cmd_group)
		return self._preamp

	@property
	def enr(self):
		"""enr commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_enr'):
			from .Enr import EnrCls
			self._enr = EnrCls(self._core, self._cmd_group)
		return self._enr

	@property
	def data(self):
		"""data commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def match(self):
		"""match commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_match'):
			from .Match import MatchCls
			self._match = MatchCls(self._core, self._cmd_group)
		return self._match

	def clone(self) -> 'UncertaintyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UncertaintyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SyncCls:
	"""Sync commands group definition. 18 total commands, 14 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sync", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Catalog import CatalogCls
			self._catalog = CatalogCls(self._core, self._cmd_group)
		return self._catalog

	@property
	def comment(self):
		"""comment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_comment'):
			from .Comment import CommentCls
			self._comment = CommentCls(self._core, self._cmd_group)
		return self._comment

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def name(self):
		"""name commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_name'):
			from .Name import NameCls
			self._name = NameCls(self._core, self._cmd_group)
		return self._name

	@property
	def nstate(self):
		"""nstate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nstate'):
			from .Nstate import NstateCls
			self._nstate = NstateCls(self._core, self._cmd_group)
		return self._nstate

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def text(self):
		"""text commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_text'):
			from .Text import TextCls
			self._text = TextCls(self._core, self._cmd_group)
		return self._text

	@property
	def found(self):
		"""found commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_found'):
			from .Found import FoundCls
			self._found = FoundCls(self._core, self._cmd_group)
		return self._found

	@property
	def iqcThreshold(self):
		"""iqcThreshold commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iqcThreshold'):
			from .IqcThreshold import IqcThresholdCls
			self._iqcThreshold = IqcThresholdCls(self._core, self._cmd_group)
		return self._iqcThreshold

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	@property
	def pattern(self):
		"""pattern commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	def copy(self, pattern: str) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:COPY \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.sync.copy(pattern = '1') \n
		This command copies a pattern file. The pattern to be copied must have been selected before using
		[SENSe:]DDEMod:SEARch:SYNC:NAME. Tip: In manual operation, a pattern can be copied in the editor by storing it under a
		new name. \n
			:param pattern: No help available
		"""
		param = Conversions.value_to_quoted_str(pattern)
		self._core.io.write(f'SENSe:DDEMod:SEARch:SYNC:COPY {param}')

	def delete(self) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:DELete \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.sync.delete() \n
		This command deletes a sync sequence. The sync sequence to be deleted must have been selected before using
		[SENSe:]DDEMod:SEARch:SYNC:NAME. \n
		"""
		self._core.io.write(f'SENSe:DDEMod:SEARch:SYNC:DELete')

	def delete_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:DELete \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.sync.delete_with_opc() \n
		This command deletes a sync sequence. The sync sequence to be deleted must have been selected before using
		[SENSe:]DDEMod:SEARch:SYNC:NAME. \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:DDEMod:SEARch:SYNC:DELete', opc_timeout_ms)

	def clone(self) -> 'SyncCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SyncCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.EnrType) -> None:
		"""SCPI: [SENSe]:CORRection:ENR:CALibration:TYPE \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.enr.calibration.typePy.set(type_py = enums.EnrType.DIODe) \n
		This command selects the type of noise source you are using for the calibration. \n
			:param type_py: DIODe Selects a noise source with diode characteristics. RESistor Selects a noise source with resistor characteristics. When you select this noise source type, the application automatically selects the manual measurement mode (see [SENSe:]CONFigure:CONTrol) . SMARt Selects a smart noise source.
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.EnrType)
		self._core.io.write(f'SENSe:CORRection:ENR:CALibration:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.EnrType:
		"""SCPI: [SENSe]:CORRection:ENR:CALibration:TYPE \n
		Snippet: value: enums.EnrType = driver.applications.k30NoiseFigure.sense.correction.enr.calibration.typePy.get() \n
		This command selects the type of noise source you are using for the calibration. \n
			:return: type_py: DIODe Selects a noise source with diode characteristics. RESistor Selects a noise source with resistor characteristics. When you select this noise source type, the application automatically selects the manual measurement mode (see [SENSe:]CONFigure:CONTrol) . SMARt Selects a smart noise source."""
		response = self._core.io.query_str(f'SENSe:CORRection:ENR:CALibration:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.EnrType)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SizeCls:
	"""Size commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("size", core, parent)

	def set(self, window_size: enums.Size, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:SIZE \n
		Snippet: driver.applications.k50Spurious.display.window.size.set(window_size = enums.Size.LARGe, window = repcap.Window.Default) \n
		This command maximizes the size of the selected result display window temporarily. To change the size of several windows
		on the screen permanently, use the method RsFswp.Applications.K30_NoiseFigure.Layout.Splitter.set command (see method
		RsFswp.Applications.K30_NoiseFigure.Layout.Splitter.set) . \n
			:param window_size: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.enum_scalar_to_str(window_size, enums.Size)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SIZE {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.Size:
		"""SCPI: DISPlay[:WINDow<n>]:SIZE \n
		Snippet: value: enums.Size = driver.applications.k50Spurious.display.window.size.get(window = repcap.Window.Default) \n
		This command maximizes the size of the selected result display window temporarily. To change the size of several windows
		on the screen permanently, use the method RsFswp.Applications.K30_NoiseFigure.Layout.Splitter.set command (see method
		RsFswp.Applications.K30_NoiseFigure.Layout.Splitter.set) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: window_size: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:SIZE?')
		return Conversions.str_to_scalar_enum(response, enums.Size)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MharmonicCls:
	"""Mharmonic commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mharmonic", core, parent)

	def set(self, harmonic: int, component=repcap.Component.Default, port=repcap.Port.Default) -> None:
		"""SCPI: [SENSe]:FPLan:COMPonent<co>:PORT<1|2>:MHARmonic \n
		Snippet: driver.applications.k50Spurious.sense.fplan.component.port.mharmonic.set(harmonic = 1, component = repcap.Component.Default, port = repcap.Port.Default) \n
		Defines the maximum harmonic of each input frequency to be considered in calculating mixer products for spur
		identification. For details see 'Frequency plan and spur identification'. \n
			:param harmonic: Range: 1 to 5
			:param component: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Component')
			:param port: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Port')
		"""
		param = Conversions.decimal_value_to_str(harmonic)
		component_cmd_val = self._cmd_group.get_repcap_cmd_value(component, repcap.Component)
		port_cmd_val = self._cmd_group.get_repcap_cmd_value(port, repcap.Port)
		self._core.io.write(f'SENSe:FPLan:COMPonent{component_cmd_val}:PORT{port_cmd_val}:MHARmonic {param}')

	def get(self, component=repcap.Component.Default, port=repcap.Port.Default) -> int:
		"""SCPI: [SENSe]:FPLan:COMPonent<co>:PORT<1|2>:MHARmonic \n
		Snippet: value: int = driver.applications.k50Spurious.sense.fplan.component.port.mharmonic.get(component = repcap.Component.Default, port = repcap.Port.Default) \n
		Defines the maximum harmonic of each input frequency to be considered in calculating mixer products for spur
		identification. For details see 'Frequency plan and spur identification'. \n
			:param component: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Component')
			:param port: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Port')
			:return: harmonic: Range: 1 to 5"""
		component_cmd_val = self._cmd_group.get_repcap_cmd_value(component, repcap.Component)
		port_cmd_val = self._cmd_group.get_repcap_cmd_value(port, repcap.Port)
		response = self._core.io.query_str(f'SENSe:FPLan:COMPonent{component_cmd_val}:PORT{port_cmd_val}:MHARmonic?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, mode: enums.ScalingMode) -> None:
		"""SCPI: [SENSe]:BWIDth:VIDeo:TYPE \n
		Snippet: driver.sense.bandwidth.video.typePy.set(mode = enums.ScalingMode.LINear) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ScalingMode)
		self._core.io.write(f'SENSe:BWIDth:VIDeo:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ScalingMode:
		"""SCPI: [SENSe]:BWIDth:VIDeo:TYPE \n
		Snippet: value: enums.ScalingMode = driver.sense.bandwidth.video.typePy.get() \n
		No command help available \n
			:return: mode: No help available"""
		response = self._core.io.query_str(f'SENSe:BWIDth:VIDeo:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.ScalingMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MeastoRefCls:
	"""MeastoRef commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: RefMeasurement, default value after init: RefMeasurement.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("meastoRef", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_refMeasurement_get', 'repcap_refMeasurement_set', repcap.RefMeasurement.Nr1)

	def repcap_refMeasurement_set(self, refMeasurement: repcap.RefMeasurement) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to RefMeasurement.Default
		Default value after init: RefMeasurement.Nr1"""
		self._cmd_group.set_repcap_enum_value(refMeasurement)

	def repcap_refMeasurement_get(self) -> repcap.RefMeasurement:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, trace=repcap.Trace.Default, refMeasurement=repcap.RefMeasurement.Default) -> None:
		"""SCPI: CONFigure:ADEMod:RESults:PM:DETector<det>:REFerence:MEAStoref<t> \n
		Snippet: driver.configure.ademod.results.pm.detector.reference.meastoRef.set(trace = repcap.Trace.Default, refMeasurement = repcap.RefMeasurement.Default) \n
		Sets the reference value to be used for relative demodulation results to the currently measured value on the specified
		trace for all relative detectors. If necessary, the detectors are activated. A reference value 0 would provide infinite
		results and is thus automatically corrected to 0.1. \n
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Detector')
			:param refMeasurement: optional repeated capability selector. Default value: Nr1 (settable in the interface 'MeastoRef')
		"""
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		refMeasurement_cmd_val = self._cmd_group.get_repcap_cmd_value(refMeasurement, repcap.RefMeasurement)
		self._core.io.write(f'CONFigure:ADEMod:RESults:PM:DETector{trace_cmd_val}:REFerence:MEAStoref{refMeasurement_cmd_val}')

	def set_with_opc(self, trace=repcap.Trace.Default, refMeasurement=repcap.RefMeasurement.Default, opc_timeout_ms: int = -1) -> None:
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		refMeasurement_cmd_val = self._cmd_group.get_repcap_cmd_value(refMeasurement, repcap.RefMeasurement)
		"""SCPI: CONFigure:ADEMod:RESults:PM:DETector<det>:REFerence:MEAStoref<t> \n
		Snippet: driver.configure.ademod.results.pm.detector.reference.meastoRef.set_with_opc(trace = repcap.Trace.Default, refMeasurement = repcap.RefMeasurement.Default) \n
		Sets the reference value to be used for relative demodulation results to the currently measured value on the specified
		trace for all relative detectors. If necessary, the detectors are activated. A reference value 0 would provide infinite
		results and is thus automatically corrected to 0.1. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Detector')
			:param refMeasurement: optional repeated capability selector. Default value: Nr1 (settable in the interface 'MeastoRef')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:ADEMod:RESults:PM:DETector{trace_cmd_val}:REFerence:MEAStoref{refMeasurement_cmd_val}', opc_timeout_ms)

	def clone(self) -> 'MeastoRefCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MeastoRefCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



"""RsFswp instrument driver
	:version: 3.0.1.7
	:copyright: 2021 by Rohde & Schwarz GMBH & Co. KG
	:license: MIT, see LICENSE for more details.
"""

__version__ = '3.0.1.7'

# Main class
from RsFswp.RsFswp import RsFswp

# Bin data format
from RsFswp.Internal.Conversions import BinIntFormat, BinFloatFormat

# Exceptions
from RsFswp.Internal.InstrumentErrors import RsInstrException, TimeoutException, StatusException, UnexpectedResponseException, ResourceError, DriverValueError

# Callback Event Argument prototypes
from RsFswp.Internal.IoTransferEventArgs import IoTransferEventArgs

# Logging Mode
from RsFswp.Internal.ScpiLogger import LoggingMode

# enums
from RsFswp import enums

# repcaps
from RsFswp import repcap



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HysteresisCls:
	"""Hysteresis commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hysteresis", core, parent)

	def set(self, hysteresis: float) -> None:
		"""SCPI: TRIGger[:SEQuence]:IFPower:HYSTeresis \n
		Snippet: driver.applications.k50Spurious.trigger.sequence.ifPower.hysteresis.set(hysteresis = 1.0) \n
		This command defines the trigger hysteresis, which is only available for 'IF Power' trigger sources. \n
			:param hysteresis: Range: 3 dB to 50 dB, Unit: DB
		"""
		param = Conversions.decimal_value_to_str(hysteresis)
		self._core.io.write(f'TRIGger:SEQuence:IFPower:HYSTeresis {param}')

	def get(self) -> float:
		"""SCPI: TRIGger[:SEQuence]:IFPower:HYSTeresis \n
		Snippet: value: float = driver.applications.k50Spurious.trigger.sequence.ifPower.hysteresis.get() \n
		This command defines the trigger hysteresis, which is only available for 'IF Power' trigger sources. \n
			:return: hysteresis: Range: 3 dB to 50 dB, Unit: DB"""
		response = self._core.io.query_str(f'TRIGger:SEQuence:IFPower:HYSTeresis?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlistCls:
	"""Slist commands group definition. 10 total commands, 7 Subgroups, 2 group commands
	Repeated Capability: TouchStone, default value after init: TouchStone.Ix1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("slist", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_touchStone_get', 'repcap_touchStone_set', repcap.TouchStone.Ix1)

	def repcap_touchStone_set(self, touchStone: repcap.TouchStone) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to TouchStone.Default
		Default value after init: TouchStone.Ix1"""
		self._cmd_group.set_repcap_enum_value(touchStone)

	def repcap_touchStone_get(self) -> repcap.TouchStone:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def size(self):
		"""size commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_size'):
			from .Size import SizeCls
			self._size = SizeCls(self._core, self._cmd_group)
		return self._size

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Catalog import CatalogCls
			self._catalog = CatalogCls(self._core, self._cmd_group)
		return self._catalog

	@property
	def remove(self):
		"""remove commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_remove'):
			from .Remove import RemoveCls
			self._remove = RemoveCls(self._core, self._cmd_group)
		return self._remove

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def insert(self):
		"""insert commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_insert'):
			from .Insert import InsertCls
			self._insert = InsertCls(self._core, self._cmd_group)
		return self._insert

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def ports(self):
		"""ports commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ports'):
			from .Ports import PortsCls
			self._ports = PortsCls(self._core, self._cmd_group)
		return self._ports

	def clear(self, inputIx=repcap.InputIx.Default, touchStone=repcap.TouchStone.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:SLISt<sli>:CLEar \n
		Snippet: driver.sense.correction.fresponse.inputPy.user.slist.clear(inputIx = repcap.InputIx.Default, touchStone = repcap.TouchStone.Default) \n
		No command help available \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
		"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		self._core.io.write(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:SLISt{touchStone_cmd_val}:CLEar')

	def clear_with_opc(self, inputIx=repcap.InputIx.Default, touchStone=repcap.TouchStone.Default, opc_timeout_ms: int = -1) -> None:
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:SLISt<sli>:CLEar \n
		Snippet: driver.sense.correction.fresponse.inputPy.user.slist.clear_with_opc(inputIx = repcap.InputIx.Default, touchStone = repcap.TouchStone.Default) \n
		No command help available \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:SLISt{touchStone_cmd_val}:CLEar', opc_timeout_ms)

	def move(self, position: enums.UpDownDirection, inputIx=repcap.InputIx.Default, touchStone=repcap.TouchStone.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:SLISt<sli>:MOVE \n
		Snippet: driver.sense.correction.fresponse.inputPy.user.slist.move(position = enums.UpDownDirection.DOWN, inputIx = repcap.InputIx.Default, touchStone = repcap.TouchStone.Default) \n
		No command help available \n
			:param position: No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
		"""
		param = Conversions.enum_scalar_to_str(position, enums.UpDownDirection)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		self._core.io.write(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:SLISt{touchStone_cmd_val}:MOVE {param}')

	def clone(self) -> 'SlistCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SlistCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, name: str, generator=repcap.Generator.Default) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator<gen>:TYPE \n
		Snippet: driver.system.communicate.rdevice.generator.typePy.set(name = '1', generator = repcap.Generator.Default) \n
		No command help available \n
			:param name: No help available
			:param generator: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Generator')
		"""
		param = Conversions.value_to_quoted_str(name)
		generator_cmd_val = self._cmd_group.get_repcap_cmd_value(generator, repcap.Generator)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:GENerator{generator_cmd_val}:TYPE {param}')

	def get(self, generator=repcap.Generator.Default) -> str:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator<gen>:TYPE \n
		Snippet: value: str = driver.system.communicate.rdevice.generator.typePy.get(generator = repcap.Generator.Default) \n
		No command help available \n
			:param generator: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Generator')
			:return: name: No help available"""
		generator_cmd_val = self._cmd_group.get_repcap_cmd_value(generator, repcap.Generator)
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:GENerator{generator_cmd_val}:TYPE?')
		return trim_str_response(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OsystemCls:
	"""Osystem commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("osystem", core, parent)

	def get(self) -> str:
		"""SCPI: SYSTem:OSYStem \n
		Snippet: value: str = driver.system.osystem.get() \n
		No command help available \n
			:return: operating_system: No help available"""
		response = self._core.io.query_str(f'SYSTem:OSYStem?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ComponentCls:
	"""Component commands group definition. 9 total commands, 7 Subgroups, 1 group commands
	Repeated Capability: Component, default value after init: Component.Ix1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("component", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_component_get', 'repcap_component_set', repcap.Component.Ix1)

	def repcap_component_set(self, component: repcap.Component) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Component.Default
		Default value after init: Component.Ix1"""
		self._cmd_group.set_repcap_enum_value(component)

	def repcap_component_get(self) -> repcap.Component:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	@property
	def bcenter(self):
		"""bcenter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bcenter'):
			from .Bcenter import BcenterCls
			self._bcenter = BcenterCls(self._core, self._cmd_group)
		return self._bcenter

	@property
	def bspan(self):
		"""bspan commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bspan'):
			from .Bspan import BspanCls
			self._bspan = BspanCls(self._core, self._cmd_group)
		return self._bspan

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import AddCls
			self._add = AddCls(self._core, self._cmd_group)
		return self._add

	@property
	def factor(self):
		"""factor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_factor'):
			from .Factor import FactorCls
			self._factor = FactorCls(self._core, self._cmd_group)
		return self._factor

	@property
	def port(self):
		"""port commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_port'):
			from .Port import PortCls
			self._port = PortCls(self._core, self._cmd_group)
		return self._port

	@property
	def identity(self):
		"""identity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_identity'):
			from .Identity import IdentityCls
			self._identity = IdentityCls(self._core, self._cmd_group)
		return self._identity

	def delete(self, component=repcap.Component.Default) -> None:
		"""SCPI: [SENSe]:FPLan:COMPonent<co>:DELete \n
		Snippet: driver.applications.k50Spurious.sense.fplan.component.delete(component = repcap.Component.Default) \n
		This command will delete the selected row from the frequency plan. \n
			:param component: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Component')
		"""
		component_cmd_val = self._cmd_group.get_repcap_cmd_value(component, repcap.Component)
		self._core.io.write(f'SENSe:FPLan:COMPonent{component_cmd_val}:DELete')

	def delete_with_opc(self, component=repcap.Component.Default, opc_timeout_ms: int = -1) -> None:
		component_cmd_val = self._cmd_group.get_repcap_cmd_value(component, repcap.Component)
		"""SCPI: [SENSe]:FPLan:COMPonent<co>:DELete \n
		Snippet: driver.applications.k50Spurious.sense.fplan.component.delete_with_opc(component = repcap.Component.Default) \n
		This command will delete the selected row from the frequency plan. \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param component: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Component')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:FPLan:COMPonent{component_cmd_val}:DELete', opc_timeout_ms)

	def clone(self) -> 'ComponentCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ComponentCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WindowCls:
	"""Window commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("window", core, parent)

	def set(self, source_window: str, target_window: str, arg_2: enums.WindowDirReplace) -> None:
		"""SCPI: LAYout:MOVE[:WINDow] \n
		Snippet: driver.applications.k70Vsa.layout.move.window.set(source_window = '1', target_window = '1', arg_2 = enums.WindowDirReplace.ABOVe) \n
		No command help available \n
			:param source_window: No help available
			:param target_window: No help available
			:param arg_2: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('source_window', source_window, DataType.String), ArgSingle('target_window', target_window, DataType.String), ArgSingle('arg_2', arg_2, DataType.Enum, enums.WindowDirReplace))
		self._core.io.write_with_opc(f'LAYout:MOVE:WINDow {param}'.rstrip())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfbWidthCls:
	"""RfbWidth commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rfbWidth", core, parent)

	def set(self, bandwidth: float, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:SBLock<sb>:RFBWidth \n
		Snippet: driver.sense.power.achannel.sblock.rfbWidth.set(bandwidth = 1.0, subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param bandwidth: No help available
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sblock')
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'SENSe:POWer:ACHannel:SBLock{subBlock_cmd_val}:RFBWidth {param}')

	def get(self, subBlock=repcap.SubBlock.Default) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:SBLock<sb>:RFBWidth \n
		Snippet: value: float = driver.sense.power.achannel.sblock.rfbWidth.get(subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sblock')
			:return: bandwidth: No help available"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:SBLock{subBlock_cmd_val}:RFBWidth?')
		return Conversions.str_to_float(response)



from enum import Enum
# noinspection PyPep8Naming
from .Internal.RepeatedCapability import VALUE_DEFAULT as DefaultRepCap
# noinspection PyPep8Naming
from .Internal.RepeatedCapability import VALUE_EMPTY as EmptyRepCap


# noinspection SpellCheckingInspection
class Channel(Enum):
	"""Repeated capability Channel"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Ch1 = 1
	Ch2 = 2
	Ch3 = 3
	Ch4 = 4
	Ch5 = 5
	Ch6 = 6
	Ch7 = 7
	Ch8 = 8
	Ch9 = 9
	Ch10 = 10
	Ch11 = 11
	Ch12 = 12
	Ch13 = 13
	Ch14 = 14
	Ch15 = 15
	Ch16 = 16
	Ch17 = 17
	Ch18 = 18
	Ch19 = 19
	Ch20 = 20
	Ch21 = 21
	Ch22 = 22
	Ch23 = 23
	Ch24 = 24
	Ch25 = 25
	Ch26 = 26
	Ch27 = 27
	Ch28 = 28
	Ch29 = 29
	Ch30 = 30
	Ch31 = 31
	Ch32 = 32
	Ch33 = 33
	Ch34 = 34
	Ch35 = 35
	Ch36 = 36
	Ch37 = 37
	Ch38 = 38
	Ch39 = 39
	Ch40 = 40
	Ch41 = 41
	Ch42 = 42
	Ch43 = 43
	Ch44 = 44
	Ch45 = 45
	Ch46 = 46
	Ch47 = 47
	Ch48 = 48
	Ch49 = 49
	Ch50 = 50
	Ch51 = 51
	Ch52 = 52
	Ch53 = 53
	Ch54 = 54
	Ch55 = 55
	Ch56 = 56
	Ch57 = 57
	Ch58 = 58
	Ch59 = 59
	Ch60 = 60
	Ch61 = 61
	Ch62 = 62
	Ch63 = 63
	Ch64 = 64


# noinspection SpellCheckingInspection
class Colors(Enum):
	"""Repeated capability Colors"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Ix1 = 1
	Ix2 = 2
	Ix3 = 3
	Ix4 = 4


# noinspection SpellCheckingInspection
class Component(Enum):
	"""Repeated capability Component"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Ix1 = 1
	Ix2 = 2
	Ix3 = 3
	Ix4 = 4
	Ix5 = 5
	Ix6 = 6
	Ix7 = 7
	Ix8 = 8
	Ix9 = 9
	Ix10 = 10
	Ix11 = 11
	Ix12 = 12
	Ix13 = 13
	Ix14 = 14
	Ix15 = 15
	Ix16 = 16
	Ix17 = 17
	Ix18 = 18
	Ix19 = 19
	Ix20 = 20
	Ix21 = 21
	Ix22 = 22
	Ix23 = 23
	Ix24 = 24
	Ix25 = 25
	Ix26 = 26
	Ix27 = 27
	Ix28 = 28
	Ix29 = 29
	Ix30 = 30
	Ix31 = 31
	Ix32 = 32


# noinspection SpellCheckingInspection
class CornerFrequency(Enum):
	"""Repeated capability CornerFrequency"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5


# noinspection SpellCheckingInspection
class DeltaMarker(Enum):
	"""Repeated capability DeltaMarker"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32


# noinspection SpellCheckingInspection
class DisplayLine(Enum):
	"""Repeated capability DisplayLine"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2


# noinspection SpellCheckingInspection
class ExternalGen(Enum):
	"""Repeated capability ExternalGen"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8


# noinspection SpellCheckingInspection
class ExternalPort(Enum):
	"""Repeated capability ExternalPort"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3


# noinspection SpellCheckingInspection
class ExternalRosc(Enum):
	"""Repeated capability ExternalRosc"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2


# noinspection SpellCheckingInspection
class FileList(Enum):
	"""Repeated capability FileList"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32
	Nr33 = 33
	Nr34 = 34
	Nr35 = 35
	Nr36 = 36
	Nr37 = 37
	Nr38 = 38
	Nr39 = 39
	Nr40 = 40
	Nr41 = 41
	Nr42 = 42
	Nr43 = 43
	Nr44 = 44
	Nr45 = 45
	Nr46 = 46
	Nr47 = 47
	Nr48 = 48
	Nr49 = 49
	Nr50 = 50
	Nr51 = 51
	Nr52 = 52
	Nr53 = 53
	Nr54 = 54
	Nr55 = 55
	Nr56 = 56
	Nr57 = 57
	Nr58 = 58
	Nr59 = 59
	Nr60 = 60
	Nr61 = 61
	Nr62 = 62
	Nr63 = 63
	Nr64 = 64


# noinspection SpellCheckingInspection
class FilterPy(Enum):
	"""Repeated capability FilterPy"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32


# noinspection SpellCheckingInspection
class FreqLine(Enum):
	"""Repeated capability FreqLine"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4


# noinspection SpellCheckingInspection
class FreqOffset(Enum):
	"""Repeated capability FreqOffset"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8


# noinspection SpellCheckingInspection
class GapChannel(Enum):
	"""Repeated capability GapChannel"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2


# noinspection SpellCheckingInspection
class GateRange(Enum):
	"""Repeated capability GateRange"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32
	Nr33 = 33
	Nr34 = 34
	Nr35 = 35
	Nr36 = 36
	Nr37 = 37
	Nr38 = 38
	Nr39 = 39
	Nr40 = 40
	Nr41 = 41
	Nr42 = 42
	Nr43 = 43
	Nr44 = 44
	Nr45 = 45
	Nr46 = 46
	Nr47 = 47
	Nr48 = 48
	Nr49 = 49
	Nr50 = 50
	Nr51 = 51
	Nr52 = 52
	Nr53 = 53
	Nr54 = 54
	Nr55 = 55
	Nr56 = 56
	Nr57 = 57
	Nr58 = 58
	Nr59 = 59
	Nr60 = 60
	Nr61 = 61
	Nr62 = 62
	Nr63 = 63
	Nr64 = 64


# noinspection SpellCheckingInspection
class Generator(Enum):
	"""Repeated capability Generator"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32


# noinspection SpellCheckingInspection
class InputIx(Enum):
	"""Repeated capability InputIx"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32


# noinspection SpellCheckingInspection
class Item(Enum):
	"""Repeated capability Item"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Ix1 = 1
	Ix2 = 2
	Ix3 = 3
	Ix4 = 4
	Ix5 = 5
	Ix6 = 6
	Ix7 = 7
	Ix8 = 8
	Ix9 = 9
	Ix10 = 10
	Ix11 = 11
	Ix12 = 12
	Ix13 = 13
	Ix14 = 14
	Ix15 = 15
	Ix16 = 16
	Ix17 = 17
	Ix18 = 18
	Ix19 = 19
	Ix20 = 20
	Ix21 = 21
	Ix22 = 22
	Ix23 = 23
	Ix24 = 24
	Ix25 = 25
	Ix26 = 26
	Ix27 = 27
	Ix28 = 28
	Ix29 = 29
	Ix30 = 30
	Ix31 = 31
	Ix32 = 32
	Ix33 = 33
	Ix34 = 34
	Ix35 = 35
	Ix36 = 36
	Ix37 = 37
	Ix38 = 38
	Ix39 = 39
	Ix40 = 40
	Ix41 = 41
	Ix42 = 42
	Ix43 = 43
	Ix44 = 44
	Ix45 = 45
	Ix46 = 46
	Ix47 = 47
	Ix48 = 48
	Ix49 = 49
	Ix50 = 50
	Ix51 = 51
	Ix52 = 52
	Ix53 = 53
	Ix54 = 54
	Ix55 = 55
	Ix56 = 56
	Ix57 = 57
	Ix58 = 58
	Ix59 = 59
	Ix60 = 60
	Ix61 = 61
	Ix62 = 62
	Ix63 = 63
	Ix64 = 64


# noinspection SpellCheckingInspection
class LimitIx(Enum):
	"""Repeated capability LimitIx"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32


# noinspection SpellCheckingInspection
class Line(Enum):
	"""Repeated capability Line"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Ix1 = 1
	Ix2 = 2
	Ix3 = 3
	Ix4 = 4
	Ix5 = 5
	Ix6 = 6
	Ix7 = 7
	Ix8 = 8


# noinspection SpellCheckingInspection
class Marker(Enum):
	"""Repeated capability Marker"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16


# noinspection SpellCheckingInspection
class MarkerDestination(Enum):
	"""Repeated capability MarkerDestination"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16


# noinspection SpellCheckingInspection
class OutputConnector(Enum):
	"""Repeated capability OutputConnector"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4


# noinspection SpellCheckingInspection
class Port(Enum):
	"""Repeated capability Port"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2


# noinspection SpellCheckingInspection
class PowerClass(Enum):
	"""Repeated capability PowerClass"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30


# noinspection SpellCheckingInspection
class PowerMeter(Enum):
	"""Repeated capability PowerMeter"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16


# noinspection SpellCheckingInspection
class Probe(Enum):
	"""Repeated capability Probe"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8


# noinspection SpellCheckingInspection
class RangePy(Enum):
	"""Repeated capability RangePy"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Ix1 = 1
	Ix2 = 2
	Ix3 = 3
	Ix4 = 4
	Ix5 = 5
	Ix6 = 6
	Ix7 = 7
	Ix8 = 8
	Ix9 = 9
	Ix10 = 10
	Ix11 = 11
	Ix12 = 12
	Ix13 = 13
	Ix14 = 14
	Ix15 = 15
	Ix16 = 16
	Ix17 = 17
	Ix18 = 18
	Ix19 = 19
	Ix20 = 20
	Ix21 = 21
	Ix22 = 22
	Ix23 = 23
	Ix24 = 24
	Ix25 = 25
	Ix26 = 26
	Ix27 = 27
	Ix28 = 28
	Ix29 = 29
	Ix30 = 30
	Ix31 = 31
	Ix32 = 32
	Ix33 = 33
	Ix34 = 34
	Ix35 = 35
	Ix36 = 36
	Ix37 = 37
	Ix38 = 38
	Ix39 = 39
	Ix40 = 40
	Ix41 = 41
	Ix42 = 42
	Ix43 = 43
	Ix44 = 44
	Ix45 = 45
	Ix46 = 46
	Ix47 = 47
	Ix48 = 48
	Ix49 = 49
	Ix50 = 50
	Ix51 = 51
	Ix52 = 52
	Ix53 = 53
	Ix54 = 54
	Ix55 = 55
	Ix56 = 56
	Ix57 = 57
	Ix58 = 58
	Ix59 = 59
	Ix60 = 60
	Ix61 = 61
	Ix62 = 62
	Ix63 = 63
	Ix64 = 64


# noinspection SpellCheckingInspection
class RefMeasurement(Enum):
	"""Repeated capability RefMeasurement"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32


# noinspection SpellCheckingInspection
class Source(Enum):
	"""Repeated capability Source"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2


# noinspection SpellCheckingInspection
class SPortPair(Enum):
	"""Repeated capability SPortPair"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Ix1 = 1
	Ix2 = 2
	Ix3 = 3
	Ix4 = 4


# noinspection SpellCheckingInspection
class Status(Enum):
	"""Repeated capability Status"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32


# noinspection SpellCheckingInspection
class Step(Enum):
	"""Repeated capability Step"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32


# noinspection SpellCheckingInspection
class Store(Enum):
	"""Repeated capability Store"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Pos1 = 1
	Pos2 = 2
	Pos3 = 3
	Pos4 = 4
	Pos5 = 5
	Pos6 = 6
	Pos7 = 7
	Pos8 = 8
	Pos9 = 9
	Pos10 = 10
	Pos11 = 11
	Pos12 = 12
	Pos13 = 13
	Pos14 = 14
	Pos15 = 15
	Pos16 = 16
	Pos17 = 17
	Pos18 = 18
	Pos19 = 19
	Pos20 = 20
	Pos21 = 21
	Pos22 = 22
	Pos23 = 23
	Pos24 = 24
	Pos25 = 25
	Pos26 = 26
	Pos27 = 27
	Pos28 = 28
	Pos29 = 29
	Pos30 = 30
	Pos31 = 31
	Pos32 = 32


# noinspection SpellCheckingInspection
class SubBlock(Enum):
	"""Repeated capability SubBlock"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8


# noinspection SpellCheckingInspection
class SubWindow(Enum):
	"""Repeated capability SubWindow"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32


# noinspection SpellCheckingInspection
class TouchStone(Enum):
	"""Repeated capability TouchStone"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Ix1 = 1
	Ix2 = 2
	Ix3 = 3
	Ix4 = 4
	Ix5 = 5
	Ix6 = 6
	Ix7 = 7
	Ix8 = 8
	Ix9 = 9
	Ix10 = 10
	Ix11 = 11
	Ix12 = 12
	Ix13 = 13
	Ix14 = 14
	Ix15 = 15
	Ix16 = 16
	Ix17 = 17
	Ix18 = 18
	Ix19 = 19
	Ix20 = 20
	Ix21 = 21
	Ix22 = 22
	Ix23 = 23
	Ix24 = 24
	Ix25 = 25
	Ix26 = 26
	Ix27 = 27
	Ix28 = 28
	Ix29 = 29
	Ix30 = 30
	Ix31 = 31
	Ix32 = 32


# noinspection SpellCheckingInspection
class Trace(Enum):
	"""Repeated capability Trace"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Tr1 = 1
	Tr2 = 2
	Tr3 = 3
	Tr4 = 4
	Tr5 = 5
	Tr6 = 6
	Tr7 = 7
	Tr8 = 8
	Tr9 = 9
	Tr10 = 10
	Tr11 = 11
	Tr12 = 12
	Tr13 = 13
	Tr14 = 14
	Tr15 = 15
	Tr16 = 16


# noinspection SpellCheckingInspection
class TriggerPort(Enum):
	"""Repeated capability TriggerPort"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8


# noinspection SpellCheckingInspection
class UpperAltChannel(Enum):
	"""Repeated capability UpperAltChannel"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32
	Nr33 = 33
	Nr34 = 34
	Nr35 = 35
	Nr36 = 36
	Nr37 = 37
	Nr38 = 38
	Nr39 = 39
	Nr40 = 40
	Nr41 = 41
	Nr42 = 42
	Nr43 = 43
	Nr44 = 44
	Nr45 = 45
	Nr46 = 46
	Nr47 = 47
	Nr48 = 48
	Nr49 = 49
	Nr50 = 50
	Nr51 = 51
	Nr52 = 52
	Nr53 = 53
	Nr54 = 54
	Nr55 = 55
	Nr56 = 56
	Nr57 = 57
	Nr58 = 58
	Nr59 = 59
	Nr60 = 60
	Nr61 = 61
	Nr62 = 62
	Nr63 = 63


# noinspection SpellCheckingInspection
class UserRange(Enum):
	"""Repeated capability UserRange"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16


# noinspection SpellCheckingInspection
class Window(Enum):
	"""Repeated capability Window"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16


# noinspection SpellCheckingInspection
class ZoomWindow(Enum):
	"""Repeated capability ZoomWindow"""
	Empty = EmptyRepCap
	Default = DefaultRepCap
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20
	Nr21 = 21
	Nr22 = 22
	Nr23 = 23
	Nr24 = 24
	Nr25 = 25
	Nr26 = 26
	Nr27 = 27
	Nr28 = 28
	Nr29 = 29
	Nr30 = 30
	Nr31 = 31
	Nr32 = 32



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MinimumCls:
	"""Minimum commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("minimum", core, parent)

	@property
	def peak(self):
		"""peak commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_peak'):
			from .Peak import PeakCls
			self._peak = PeakCls(self._core, self._cmd_group)
		return self._peak

	@property
	def left(self):
		"""left commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_left'):
			from .Left import LeftCls
			self._left = LeftCls(self._core, self._cmd_group)
		return self._left

	@property
	def next(self):
		"""next commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_next'):
			from .Next import NextCls
			self._next = NextCls(self._core, self._cmd_group)
		return self._next

	@property
	def right(self):
		"""right commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_right'):
			from .Right import RightCls
			self._right = RightCls(self._core, self._cmd_group)
		return self._right

	def clone(self) -> 'MinimumCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MinimumCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OtypeCls:
	"""Otype commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("otype", core, parent)

	def set(self, type_py: enums.TriggerOutType, triggerPort=repcap.TriggerPort.Default) -> None:
		"""SCPI: OUTPut:TRIGger<tp>:OTYPe \n
		Snippet: driver.applications.k50Spurious.output.trigger.otype.set(type_py = enums.TriggerOutType.DEVice, triggerPort = repcap.TriggerPort.Default) \n
		This command selects the type of signal generated at the trigger output. \n
			:param type_py: No help available
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.TriggerOutType)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		self._core.io.write(f'OUTPut:TRIGger{triggerPort_cmd_val}:OTYPe {param}')

	# noinspection PyTypeChecker
	def get(self, triggerPort=repcap.TriggerPort.Default) -> enums.TriggerOutType:
		"""SCPI: OUTPut:TRIGger<tp>:OTYPe \n
		Snippet: value: enums.TriggerOutType = driver.applications.k50Spurious.output.trigger.otype.get(triggerPort = repcap.TriggerPort.Default) \n
		This command selects the type of signal generated at the trigger output. \n
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:return: type_py: No help available"""
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		response = self._core.io.query_str(f'OUTPut:TRIGger{triggerPort_cmd_val}:OTYPe?')
		return Conversions.str_to_scalar_enum(response, enums.TriggerOutType)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpacingCls:
	"""Spacing commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spacing", core, parent)

	def set(self, interpol_type: enums.ScalingMode, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:UPPer:SPACing \n
		Snippet: driver.calculate.limit.upper.spacing.set(interpol_type = enums.ScalingMode.LINear, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command selects linear or logarithmic interpolation for the calculation of an upper limit line from one horizontal
		point to the next. \n
			:param interpol_type: LINear | LOGarithmic
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.enum_scalar_to_str(interpol_type, enums.ScalingMode)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:UPPer:SPACing {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> enums.ScalingMode:
		"""SCPI: CALCulate<n>:LIMit<li>:UPPer:SPACing \n
		Snippet: value: enums.ScalingMode = driver.calculate.limit.upper.spacing.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command selects linear or logarithmic interpolation for the calculation of an upper limit line from one horizontal
		point to the next. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: interpol_type: LINear | LOGarithmic"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:UPPer:SPACing?')
		return Conversions.str_to_scalar_enum(response, enums.ScalingMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CfrequencyCls:
	"""Cfrequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cfrequency", core, parent)

	def set(self, frequency: float, outputConnector=repcap.OutputConnector.Default) -> None:
		"""SCPI: OUTPut<up>:ADEMod[:ONLine]:AF[:CFRequency] \n
		Snippet: driver.output.ademod.online.af.cfrequency.set(frequency = 1.0, outputConnector = repcap.OutputConnector.Default) \n
		This command defines the cutoff frequency for the AC highpass filter (for AC coupling only,
		see [SENSe:]ADEMod<n>:AF:COUPling) . \n
			:param frequency: numeric value Range: 10 Hz to DemodBW/10 (= 300 kHz for active demodulation output) , Unit: HZ
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.decimal_value_to_str(frequency)
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		self._core.io.write(f'OUTPut{outputConnector_cmd_val}:ADEMod:ONLine:AF:CFRequency {param}')

	def get(self, outputConnector=repcap.OutputConnector.Default) -> float:
		"""SCPI: OUTPut<up>:ADEMod[:ONLine]:AF[:CFRequency] \n
		Snippet: value: float = driver.output.ademod.online.af.cfrequency.get(outputConnector = repcap.OutputConnector.Default) \n
		This command defines the cutoff frequency for the AC highpass filter (for AC coupling only,
		see [SENSe:]ADEMod<n>:AF:COUPling) . \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: frequency: numeric value Range: 10 Hz to DemodBW/10 (= 300 kHz for active demodulation output) , Unit: HZ"""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		response = self._core.io.query_str(f'OUTPut{outputConnector_cmd_val}:ADEMod:ONLine:AF:CFRequency?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SlopeCls:
	"""Slope commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("slope", core, parent)

	def set(self, type_py: enums.SlopeType) -> None:
		"""SCPI: TRIGger[:SEQuence]:SLOPe \n
		Snippet: driver.applications.k60Transient.trigger.sequence.slope.set(type_py = enums.SlopeType.NEGative) \n
		This command selects the trigger slope. \n
			:param type_py: POSitive | NEGative POSitive Triggers when the signal rises to the trigger level (rising edge) . NEGative Triggers when the signal drops to the trigger level (falling edge) .
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.SlopeType)
		self._core.io.write(f'TRIGger:SEQuence:SLOPe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SlopeType:
		"""SCPI: TRIGger[:SEQuence]:SLOPe \n
		Snippet: value: enums.SlopeType = driver.applications.k60Transient.trigger.sequence.slope.get() \n
		This command selects the trigger slope. \n
			:return: type_py: POSitive | NEGative POSitive Triggers when the signal rises to the trigger level (rising edge) . NEGative Triggers when the signal drops to the trigger level (falling edge) ."""
		response = self._core.io.query_str(f'TRIGger:SEQuence:SLOPe?')
		return Conversions.str_to_scalar_enum(response, enums.SlopeType)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DescriptionCls:
	"""Description commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("description", core, parent)

	def set(self, description: str) -> None:
		"""SCPI: HCOPy:TREPort:DESCription \n
		Snippet: driver.hardCopy.treport.description.set(description = '1') \n
		No command help available \n
			:param description: No help available
		"""
		param = Conversions.value_to_quoted_str(description)
		self._core.io.write(f'HCOPy:TREPort:DESCription {param}')

	def get(self) -> str:
		"""SCPI: HCOPy:TREPort:DESCription \n
		Snippet: value: str = driver.hardCopy.treport.description.get() \n
		No command help available \n
			:return: description: No help available"""
		response = self._core.io.query_str(f'HCOPy:TREPort:DESCription?')
		return trim_str_response(response)
